==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
var GridFilterDialogViewModelGroupingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridFilterDialogViewModelGroupingDescriptionMetadata, _super);
    function GridFilterDialogViewModelGroupingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.b = function (a) {
        if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        if (a.g(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
            return;
        }
        a.s(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("IsOrGrouping", "Boolean");
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.d = function (a) {
        GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
        a.u("GridFilterDialogViewModelGrouping", function () { return new GridFilterDialogViewModelGroupingDescription(); });
        a.t("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
}(Base));
export { GridFilterDialogViewModelGroupingDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
var GridFilterDialogViewModelGroupingDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridFilterDialogViewModelGroupingDescriptionMetadata, _super);
    function GridFilterDialogViewModelGroupingDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.b = function (a) {
        if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        if (a.j(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
            return;
        }
        a.y(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.c = function (a) {
        a.item("StartIndex", "Number:int");
        a.item("EndIndex", "Number:int");
        a.item("IsOrGrouping", "Boolean");
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.d = function (a) {
        GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
        a.aa("GridFilterDialogViewModelGrouping", function () { return new GridFilterDialogViewModelGroupingDescription(); });
        a.z("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
    };
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
}(Base));
export { GridFilterDialogViewModelGroupingDescriptionMetadata };
